@@ -73,6 +73,7 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
     m_editor->connectionsWidget->setSortingEnabled(false);
     m_editor->connectionsWidget->sortByColumn(0, Qt::AscendingOrder);
     m_editor->connectionsWidget->setSortingEnabled(true);
+    m_editor->connectionsWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
     m_editor->connectionsWidget->setContextMenuPolicy(Qt::CustomContextMenu);
 
     m_editor->messageWidget->hide();
@@ -96,13 +97,11 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
         grp2.writeEntry("FirstStart", false);
     }
 
-    connect(m_editor->connectionsWidget->selectionModel(), &QItemSelectionModel::currentChanged, this, &ConnectionEditor::slotSelectionChanged);
+    connect(m_editor->connectionsWidget->selectionModel(), &QItemSelectionModel::selectionChanged, this, &ConnectionEditor::slotSelectionChanged);
     connect(m_editor->connectionsWidget, &QTreeView::doubleClicked, this, &ConnectionEditor::slotItemDoubleClicked);
     connect(m_editor->connectionsWidget, &QTreeView::customContextMenuRequested, this, &ConnectionEditor::slotContextMenuRequested);
-    connect(m_menu->menu(), SIGNAL(triggered(QAction*)),
-            SLOT(addConnection(QAction*)));
-    connect(NetworkManager::settingsNotifier(), SIGNAL(connectionAdded(QString)),
-            SLOT(connectionAdded(QString)));
+    connect(m_menu->menu(), &QMenu::triggered, this, static_cast<void (ConnectionEditor::*)(QAction*)>(&ConnectionEditor::addConnection));
+    connect(NetworkManager::settingsNotifier(), &NetworkManager::SettingsNotifier::connectionAdded, this, &ConnectionEditor::connectionAdded);
 
     QLoggingCategory::setFilterRules(QStringLiteral("plasma-nm.debug = false"));
     QLoggingCategory::setFilterRules(QStringLiteral("plasma-nm.warning = true"));
@@ -227,10 +226,9 @@ void ConnectionEditor::initializeMenu()
     kAction->setEnabled(false);
     connect(kAction, &QAction::triggered, this, &ConnectionEditor::exportVpn);
 
-    m_menuBarAction = KStandardAction::showMenubar(this, SLOT(slotShowMenuBar()), actionCollection());
+    KStandardAction::showMenubar(menuBar(), SLOT(setVisible(bool)), actionCollection());
     KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
     KStandardAction::quit(this, SLOT(close()), actionCollection());
-
     setupGUI(QSize(480, 480));
 
     setAutoSaveSettings();
@@ -364,7 +362,7 @@ void ConnectionEditor::connectionAdded(const QString& connection)
     m_editor->messageWidget->animatedShow();
     m_editor->messageWidget->setMessageType(KMessageWidget::Positive);
     m_editor->messageWidget->setText(i18n("Connection %1 has been added", con->name()));
-    QTimer::singleShot(5000, m_editor->messageWidget, SLOT(animatedHide()));
+    QTimer::singleShot(5000, m_editor->messageWidget, &KMessageWidget::animatedHide);
 }
 
 void ConnectionEditor::connectConnection()
@@ -391,7 +389,7 @@ void ConnectionEditor::dataChanged(const QModelIndex& topLeft, const QModelIndex
             QModelIndex index = m_editor->connectionsWidget->model()->index(i, 0);
             if (index.isValid() && index == currentIndex) {
                 // Re-check enabled/disabled actions
-                slotSelectionChanged(currentIndex, currentIndex);
+                slotSelectionChanged();
                 break;
             }
         }
@@ -436,28 +434,50 @@ void ConnectionEditor::initializeConnections()
 
 void ConnectionEditor::removeConnection()
 {
-    const QModelIndex currentIndex = m_editor->connectionsWidget->currentIndex();
+    QModelIndexList selected = m_editor->connectionsWidget->selectionModel()->selectedRows();
 
-    if (!currentIndex.isValid() || currentIndex.parent().isValid()) {
-        return;
-    }
+    QList<NetworkManager::Connection::Ptr> connections;
+    QString connectionNames = QString("\n");
+    bool removeConnections;
 
-    NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(currentIndex.data(NetworkModel::UuidRole).toString());
+    Q_FOREACH( const QModelIndex& currentIndex, selected ) {
 
-    if (!connection) {
-        return;
-    }
-
-    if (KMessageBox::questionYesNo(this, i18n("Do you want to remove the connection '%1'?", connection->name()), i18n("Remove Connection"), KStandardGuiItem::remove(),
-                                   KStandardGuiItem::no(), QString(), KMessageBox::Dangerous)
-            == KMessageBox::Yes) {
-        Q_FOREACH (const NetworkManager::Connection::Ptr &con, NetworkManager::listConnections()) {
-            NetworkManager::ConnectionSettings::Ptr settings = con->settings();
-            if (settings->master() == connection->uuid()) {
-                m_handler->removeConnection(con->path());
-            }
+        if (!currentIndex.isValid() || currentIndex.parent().isValid()) {
+            return;
         }
-        m_handler->removeConnection(connection->path());
+
+        NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(currentIndex.data(NetworkModel::UuidRole).toString());
+
+        if (connection) {
+            connections.append(connection);
+            connectionNames.append(QString("• %1\n").arg(connection->name()));
+        }
+    }
+
+    connectionNames = connectionNames.remove(connectionNames.size()-1,1);
+
+    if (connections.size() == 1) {
+        removeConnections = KMessageBox::questionYesNo(this, i18n("Do you want to remove the connection '%1'?", connectionNames), i18n("Remove Connection"),
+                                   KStandardGuiItem::remove(), KStandardGuiItem::no(), QString(), KMessageBox::Dangerous)
+        == KMessageBox::Yes;
+    } else if (connections.size() > 1) {
+        removeConnections = KMessageBox::questionYesNo(this, i18n("Do you want to remove the following connections: %1", connectionNames), i18n("Remove Connections"),
+                                                       KStandardGuiItem::remove(), KStandardGuiItem::no(), QString(), KMessageBox::Dangerous)
+        == KMessageBox::Yes;
+    }
+
+    Q_FOREACH( NetworkManager::Connection::Ptr connection, connections ) {
+
+        if (removeConnections) {
+            Q_FOREACH (const NetworkManager::Connection::Ptr &con, NetworkManager::listConnections()) {
+                NetworkManager::ConnectionSettings::Ptr settings = con->settings();
+                if (settings->master() == connection->uuid()) {
+                    m_handler->removeConnection(con->path());
+                }
+            }
+            m_handler->removeConnection(connection->path());
+        }
+
     }
 }
 
@@ -479,35 +499,35 @@ void ConnectionEditor::slotContextMenuRequested(const QPoint&)
     menu->exec(QCursor::pos());
 }
 
-void ConnectionEditor::slotSelectionChanged(const QModelIndex &index, const QModelIndex &previous)
+void ConnectionEditor::slotSelectionChanged()
 {
-    Q_UNUSED(previous);
+    QModelIndexList selected = m_editor->connectionsWidget->selectionModel()->selectedRows();
 
-    if (!index.isValid()) {
-        return;
-    }
+    bool singleSelection = (selected.size() == 1);
 
     //qCDebug(PLASMA_NM) << "Clicked item" << index.data(NetworkModel::UuidRole).toString();
 
-    if (index.parent().isValid()) { // category
+    if (selected.size() >= 1) {                       //connection
+        QModelIndex index = selected.at(0);
+
+        const bool isActive = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
+        const bool isActivating = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activating;
+        const bool isAvailable = (NetworkModelItem::ItemType)index.data(NetworkModel::ItemTypeRole).toUInt() == NetworkModelItem::AvailableConnection;
+
+        actionCollection()->action("connect_connection")->setEnabled(singleSelection && isAvailable && !isActive && !isActivating);
+        actionCollection()->action("disconnect_connection")->setEnabled(singleSelection && isAvailable && (isActive || isActivating));
+        actionCollection()->action("edit_connection")->setEnabled(singleSelection);
+        actionCollection()->action("delete_connection")->setEnabled(true);
+        const bool isVpn = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(index.data(NetworkModel::TypeRole).toUInt()) ==
+                        NetworkManager::ConnectionSettings::Vpn;
+        actionCollection()->action("export_vpn")->setEnabled(singleSelection && isVpn);
+    } else { // category
         actionCollection()->action("connect_connection")->setEnabled(false);
         actionCollection()->action("disconnect_connection")->setEnabled(false);
         actionCollection()->action("edit_connection")->setEnabled(false);
         actionCollection()->action("delete_connection")->setEnabled(false);
         actionCollection()->action("export_vpn")->setEnabled(false);
         actionCollection()->action("export_vpn")->setEnabled(false);
-    } else {                       //connection
-        const bool isActive = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
-        const bool isActivating = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activating;
-        const bool isAvailable = (NetworkModelItem::ItemType)index.data(NetworkModel::ItemTypeRole).toUInt() == NetworkModelItem::AvailableConnection;
-
-        actionCollection()->action("connect_connection")->setEnabled(isAvailable && !isActive && !isActivating);
-        actionCollection()->action("disconnect_connection")->setEnabled(isAvailable && (isActive || isActivating));
-        actionCollection()->action("edit_connection")->setEnabled(true);
-        actionCollection()->action("delete_connection")->setEnabled(true);
-        const bool isVpn = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(index.data(NetworkModel::TypeRole).toUInt()) ==
-                           NetworkManager::ConnectionSettings::Vpn;
-        actionCollection()->action("export_vpn")->setEnabled(isVpn);
     }
 }
 
@@ -541,11 +561,6 @@ void ConnectionEditor::slotItemDoubleClicked(const QModelIndex &index)
     editor->show();
 }
 
-void ConnectionEditor::slotShowMenuBar()
-{
-    menuBar()->setVisible(m_menuBarAction->isChecked());
-}
-
 void ConnectionEditor::importSecretsFromPlainTextFiles()
 {
     const QString secretsDirectory = QStandardPaths::locate(QStandardPaths::DataLocation, "networkmanagement/secrets/", QStandardPaths::LocateDirectory);
@@ -640,7 +655,7 @@ void ConnectionEditor::importVpn()
                     m_editor->messageWidget->animatedShow();
                     m_editor->messageWidget->setMessageType(KMessageWidget::Error);
                     m_editor->messageWidget->setText(i18n("Importing VPN connection %1 failed\n%2", fi.fileName(), vpnPlugin->lastErrorMessage()));
-                    QTimer::singleShot(5000, m_editor->messageWidget, SLOT(animatedHide()));
+                    QTimer::singleShot(5000, m_editor->messageWidget, &KMessageWidget::animatedHide);
                 } else {
                     delete vpnPlugin;
                     break; // stop iterating over the plugins if the import produced at least some output
@@ -684,7 +699,7 @@ void ConnectionEditor::exportVpn()
             m_editor->messageWidget->animatedShow();
             m_editor->messageWidget->setMessageType(KMessageWidget::Error);
             m_editor->messageWidget->setText(i18n("Export is not supported by this VPN type"));
-            QTimer::singleShot(5000, m_editor->messageWidget, SLOT(animatedHide()));
+            QTimer::singleShot(5000, m_editor->messageWidget, &KMessageWidget::animatedHide);
             return;
         }
 
@@ -695,12 +710,12 @@ void ConnectionEditor::exportVpn()
                 m_editor->messageWidget->animatedShow();
                 m_editor->messageWidget->setMessageType(KMessageWidget::Error);
                 m_editor->messageWidget->setText(i18n("Exporting VPN connection %1 failed\n%2", connection->name(), vpnPlugin->lastErrorMessage()));
-                QTimer::singleShot(5000, m_editor->messageWidget, SLOT(animatedHide()));
+                QTimer::singleShot(5000, m_editor->messageWidget, &KMessageWidget::animatedHide);
             } else {
                 m_editor->messageWidget->animatedShow();
                 m_editor->messageWidget->setMessageType(KMessageWidget::Positive);
                 m_editor->messageWidget->setText(i18n("VPN connection %1 exported successfully", connection->name()));
-                QTimer::singleShot(5000, m_editor->messageWidget, SLOT(animatedHide()));
+                QTimer::singleShot(5000, m_editor->messageWidget, &KMessageWidget::animatedHide);
             }
         }
         delete vpnPlugin;
