@@ -89,6 +89,8 @@ void ConnectionDetailEditor::initEditor()
 {
     enableOKButton(false);
 
+    initTabs();
+
     if (!m_new) {
         NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(m_connection->uuid());
         if (connection) {
@@ -184,16 +186,12 @@ void ConnectionDetailEditor::initEditor()
                     reply = connection->secrets(settingName);
                     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
                     watcher->setProperty("connection", connection->name());
+                    watcher->setProperty("settingName", settingName);
                     connect(watcher, &QDBusPendingCallWatcher::finished, this, &ConnectionDetailEditor::replyFinished);
-                } else {
-                   initTabs();
+                    enableOKButton(false);
                 }
-            } else {
-                initTabs();
             }
         }
-    } else {
-        initTabs();
     }
 
     if (m_connection->id().isEmpty()) {
@@ -304,22 +302,25 @@ void ConnectionDetailEditor::initTabs()
         m_ui->tabWidget->addTab(pppWidget, i18n("PPP"));
     }
 
-    // TODO virtual connections
-//     IPv4 widget
+    // IPv4 widget
     if (!m_connection->isSlave()) {
         IPv4Widget * ipv4Widget = new IPv4Widget(m_connection->setting(NetworkManager::Setting::Ipv4), this);
         m_ui->tabWidget->addTab(ipv4Widget, i18n("IPv4"));
     }
 
-    // TODO virtual connections
     // IPv6 widget
     if ((type == NetworkManager::ConnectionSettings::Wired
          || type == NetworkManager::ConnectionSettings::Wireless
          || type == NetworkManager::ConnectionSettings::Infiniband
          || type == NetworkManager::ConnectionSettings::Wimax
-    #if NM_CHECK_VERSION(0, 9, 10)
+#if NM_CHECK_VERSION(0, 9, 10)
          || type == NetworkManager::ConnectionSettings::Team
-     #endif
+#endif
+
+#if NM_CHECK_VERSION(1, 0, 0)
+         || type == NetworkManager::ConnectionSettings::Cdma
+         || type == NetworkManager::ConnectionSettings::Gsm
+#endif
          || type == NetworkManager::ConnectionSettings::Bond
          || type == NetworkManager::ConnectionSettings::Bridge
          || type == NetworkManager::ConnectionSettings::Vlan
@@ -407,12 +408,24 @@ NMVariantMapMap ConnectionDetailEditor::setting()
 void ConnectionDetailEditor::replyFinished(QDBusPendingCallWatcher *watcher)
 {
     QDBusPendingReply<NMVariantMapMap> reply = *watcher;
+    const QString settingName = watcher->property("settingName").toString();
     if (reply.isValid()) {
         NMVariantMapMap secrets = reply.argumentAt<0>();
         Q_FOREACH (const QString & key, secrets.keys()) {
-            NetworkManager::Setting::Ptr setting = m_connection->setting(NetworkManager::Setting::typeFromString(key));
-            if (setting) {
-                setting->secretsFromMap(secrets.value(key));
+            if (key == settingName) {
+                NetworkManager::Setting::Ptr setting = m_connection->setting(NetworkManager::Setting::typeFromString(key));
+                if (setting) {
+                    setting->secretsFromMap(secrets.value(key));
+                    for (int i = 1; i < m_ui->tabWidget->count(); ++i) {
+                        SettingWidget *widget = static_cast<SettingWidget*>(m_ui->tabWidget->widget(i));
+                        const QString type = widget->type();
+                        if (type == settingName ||
+                            (settingName == NetworkManager::Setting::typeAsString(NetworkManager::Setting::Security8021x) &&
+                             type == NetworkManager::Setting::typeAsString(NetworkManager::Setting::WirelessSecurity))) {
+                            widget->loadSecrets(setting);
+                        }
+                    }
+                }
             }
         }
     } else {
@@ -427,8 +440,8 @@ void ConnectionDetailEditor::replyFinished(QDBusPendingCallWatcher *watcher)
         connect(this, &ConnectionDetailEditor::rejected, notification, &KNotification::close);
     }
 
-    initTabs();
     watcher->deleteLater();
+    validChanged(true);
 }
 
 void ConnectionDetailEditor::validChanged(bool valid)
