@@ -43,16 +43,16 @@ GsmWidget::GsmWidget(const NetworkManager::Setting::Ptr &setting, QWidget* paren
     m_ui->type->addItem(i18n("Prefer 4G (LTE)"), NetworkManager::GsmSetting::Prefer4GLte);
     m_ui->type->addItem(i18n("4G Only (LTE)"), NetworkManager::GsmSetting::Only4GLte);
 
-    connect(m_ui->cbShowPasswords, SIGNAL(toggled(bool)), SLOT(showPasswords(bool)));
-    connect(m_ui->pinStorage, SIGNAL(currentIndexChanged(int)), SLOT(pinStorageChanged(int)));
-    connect(m_ui->passwordStorage, SIGNAL(currentIndexChanged(int)), SLOT(passwordStorageChanged(int)));
+    connect(m_ui->cbShowPasswords, &QCheckBox::toggled, this, &GsmWidget::showPasswords);
+    connect(m_ui->pinStorage, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &GsmWidget::pinStorageChanged);
+    connect(m_ui->passwordStorage, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &GsmWidget::passwordStorageChanged);
 
-    connect(m_ui->apn, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
-    connect(m_ui->password, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
-    connect(m_ui->pin, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
-    connect(m_ui->username, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
-    connect(m_ui->passwordStorage, SIGNAL(currentIndexChanged(int)), SLOT(slotWidgetChanged()));
-    connect(m_ui->pinStorage, SIGNAL(currentIndexChanged(int)), SLOT(slotWidgetChanged()));
+    connect(m_ui->apn, &KLineEdit::textChanged, this, &GsmWidget::slotWidgetChanged);
+    connect(m_ui->password, &KLineEdit::textChanged, this, &GsmWidget::slotWidgetChanged);
+    connect(m_ui->pin, &KLineEdit::textChanged, this, &GsmWidget::slotWidgetChanged);
+    connect(m_ui->username, &KLineEdit::textChanged, this, &GsmWidget::slotWidgetChanged);
+    connect(m_ui->passwordStorage, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &GsmWidget::slotWidgetChanged);
+    connect(m_ui->pinStorage, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &GsmWidget::slotWidgetChanged);
 
     KAcceleratorManager::manage(this);
 
@@ -73,10 +73,9 @@ void GsmWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
     if (!number.isEmpty())
         m_ui->number->setText(number);
     m_ui->username->setText(gsmSetting->username());
-    if ((!gsmSetting->password().isEmpty() && gsmSetting->passwordFlags().testFlag(NetworkManager::Setting::None)) ||
+    if (gsmSetting->passwordFlags().testFlag(NetworkManager::Setting::None) ||
         gsmSetting->passwordFlags().testFlag(NetworkManager::Setting::AgentOwned)) {
         m_ui->passwordStorage->setCurrentIndex(SettingWidget::EnumPasswordStorageType::Store);
-        m_ui->password->setText(gsmSetting->password());
     } else if (gsmSetting->passwordFlags().testFlag(NetworkManager::Setting::NotSaved)) {
         m_ui->passwordStorage->setCurrentIndex(SettingWidget::EnumPasswordStorageType::AlwaysAsk);
     } else {
@@ -87,15 +86,33 @@ void GsmWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
     if (gsmSetting->networkType() != NetworkManager::GsmSetting::Any)
         m_ui->type->setCurrentIndex(m_ui->type->findData(static_cast<int>(gsmSetting->networkType())));
     m_ui->roaming->setChecked(!gsmSetting->homeOnly());
-    if ((!gsmSetting->pin().isEmpty() && gsmSetting->pinFlags() == NetworkManager::Setting::None) ||
+    if (gsmSetting->pinFlags() == NetworkManager::Setting::None ||
         gsmSetting->pinFlags() == NetworkManager::Setting::AgentOwned) {
         m_ui->pinStorage->setCurrentIndex(SettingWidget::EnumPasswordStorageType::Store);
-        m_ui->pin->setText(gsmSetting->pin());
     } else if (gsmSetting->pinFlags() == NetworkManager::Setting::NotSaved) {
         m_ui->pinStorage->setCurrentIndex(SettingWidget::EnumPasswordStorageType::AlwaysAsk);
     } else {
         m_ui->pinStorage->setCurrentIndex(SettingWidget::EnumPasswordStorageType::NotRequired);
     }
+
+    loadSecrets(setting);
+}
+
+void GsmWidget::loadSecrets(const NetworkManager::Setting::Ptr &setting)
+{
+    NetworkManager::GsmSetting::Ptr gsmSetting = setting.staticCast<NetworkManager::GsmSetting>();
+
+    if (gsmSetting) {
+        const QString password = gsmSetting->password();
+        if (!password.isEmpty()) {
+            m_ui->password->setText(password);
+        }
+
+        const QString pin = gsmSetting->pin();
+        if (!pin.isEmpty()) {
+            m_ui->pin->setText(pin);
+        }
+    }
 }
 
 QVariantMap GsmWidget::setting(bool agentOwned) const
