@@ -29,26 +29,27 @@
 #include <QPointer>
 #include <QDBusMetaType>
 
-L2tpWidget::L2tpWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget* parent, Qt::WindowFlags f):
-    SettingWidget(setting, parent, f),
-    m_ui(new Ui::L2tpWidget),
-    m_setting(setting)
+L2tpWidget::L2tpWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget* parent, Qt::WindowFlags f)
+    : SettingWidget(setting, parent, f)
+    , m_ui(new Ui::L2tpWidget)
+    , m_setting(setting)
 {
     qDBusRegisterMetaType<NMStringMap>();
 
     m_ui->setupUi(this);
 
-    connect(m_ui->cboUserPasswordType, SIGNAL(currentIndexChanged(int)), SLOT(userPasswordTypeChanged(int)));
-    connect(m_ui->cbShowPassword, SIGNAL(toggled(bool)), SLOT(showPassword(bool)));
-    connect(m_ui->btnIPSecSettings, SIGNAL(clicked(bool)), SLOT(showAdvanced()));
-    connect(m_ui->btnPPPSettings, SIGNAL(clicked(bool)), SLOT(showPpp()));
+    connect(m_ui->cboUserPasswordType, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &L2tpWidget::userPasswordTypeChanged);
+    connect(m_ui->cbShowPassword, &QCheckBox::toggled, this, &L2tpWidget::showPassword);
+    connect(m_ui->btnIPSecSettings, &QPushButton::clicked, this, &L2tpWidget::showAdvanced);
+    connect(m_ui->btnPPPSettings, &QPushButton::clicked, this, &L2tpWidget::showPpp);
 
-    connect(m_ui->gateway, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
+    connect(m_ui->gateway, &QLineEdit::textChanged, this, &L2tpWidget::slotWidgetChanged);
 
     KAcceleratorManager::manage(this);
 
-    if (m_setting)
+    if (m_setting) {
         loadConfig(setting);
+    }
 }
 
 L2tpWidget::~L2tpWidget()
@@ -63,7 +64,6 @@ void L2tpWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
     Q_UNUSED(setting);
 
     const NMStringMap data = m_setting->data();
-    const NMStringMap secrets = m_setting->secrets();
 
     const QString gateway = data.value(NM_L2TP_KEY_GATEWAY);
     if (!gateway.isEmpty()) {
@@ -75,11 +75,6 @@ void L2tpWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
         m_ui->username->setText(user);
     }
 
-    const QString userPassword = secrets.value(NM_L2TP_KEY_PASSWORD);
-    if (!userPassword.isEmpty()) {
-        m_ui->password->setText(userPassword);
-    }
-
     const NetworkManager::Setting::SecretFlags userPassType = static_cast<NetworkManager::Setting::SecretFlags>(data.value(NM_L2TP_KEY_PASSWORD"-flags").toInt());
     if (userPassType.testFlag(NetworkManager::Setting::NotSaved)) {
         m_ui->cboUserPasswordType->setCurrentIndex(SettingWidget::EnumPasswordStorageType::AlwaysAsk);
@@ -93,6 +88,21 @@ void L2tpWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
     if (!domain.isEmpty()) {
         m_ui->domain->setText(domain);
     }
+
+    loadSecrets(setting);
+}
+
+void L2tpWidget::loadSecrets(const NetworkManager::Setting::Ptr &setting)
+{
+    NetworkManager::VpnSetting::Ptr vpnSetting = setting.staticCast<NetworkManager::VpnSetting>();
+
+    if (vpnSetting) {
+        const NMStringMap secrets = vpnSetting->secrets();
+        const QString userPassword = secrets.value(NM_L2TP_KEY_PASSWORD);
+        if (!userPassword.isEmpty()) {
+            m_ui->password->setText(userPassword);
+        }
+    }
 }
 
 QVariantMap L2tpWidget::setting(bool agentOwned) const
@@ -133,8 +143,9 @@ QVariantMap L2tpWidget::setting(bool agentOwned) const
         }
     }
 
-    if (!m_ui->domain->text().isEmpty())
+    if (!m_ui->domain->text().isEmpty()) {
         data.insert(NM_L2TP_KEY_DOMAIN, m_ui->domain->text());
+    }
 
     setting.setData(data);
     setting.setSecrets(secrets);
@@ -149,10 +160,11 @@ void L2tpWidget::userPasswordTypeChanged(int index)
 
 void L2tpWidget::showPassword(bool show)
 {
-    if (show)
+    if (show) {
         m_ui->password->setEchoMode(QLineEdit::Normal);
-    else
+    } else {
         m_ui->password->setEchoMode(QLineEdit::Password);
+    }
 }
 
 void L2tpWidget::showAdvanced()
